@@ -257,6 +257,55 @@ get_options (struct mail_opt *opts, int argc, char *argv[])
   return -1;
 }
 
+/*
+ * get options from the configuration file
+ */
+static int
+get_cfg_options(char *path, struct mail_opt *o)
+{
+  FILE *CFG;
+  char opt[129];
+  char *p;
+  char *pnt;
+  if(path == NULL)
+    {
+      path = getenv("HOME");
+      if((p = malloc(strlen(path) + strlen("/.smtpmail") + 1)) == NULL)
+	return -1;
+      strcat(p, path);
+      strcat(p, "/.smtpmail");
+    }
+
+  if((CFG = fopen(p, "r")) == NULL)
+    return -2;
+  while(fgets(opt, 128, CFG) != NULL)
+    {
+      if(strstr(opt, ":") == NULL)
+	continue;
+      if(strstr(opt, "#"))
+	continue;
+      if(!strncmp(opt, "host:", strlen("host:")))
+	{
+	  pnt = opt+strlen("host:");
+	  pnt += strspn(pnt, " \t");
+	  if((o->host = realloc(o->host, strlen(pnt))) == NULL)
+	    return -3;
+	  snprintf(o->host, strlen(pnt), "%s", pnt);
+	}
+      if(!strncmp(opt, "from:", strlen("from:")))
+	{
+	  pnt = opt+strlen("from:");
+	  pnt += strspn(pnt, " \t");
+	  if((o->sender = realloc(o->sender, strlen(pnt))) == NULL)
+	    return -3;
+	  snprintf(o->sender, strlen(pnt), "%s", pnt);
+	}
+    }
+  free(p);
+  return 0;
+}
+
+
 /*
  * read the mailbody
  */
@@ -343,6 +392,7 @@ main (int argc, char *argv[])
   struct mail_opt opts;
 
   init_opts (&opts);
+  get_cfg_options(NULL, &opts);
   if (get_options (&opts, argc - 1, argv))
     return usage (argv[0]);
   if (read_body (argv[argc - 1], &opts.msg))
